<?php
namespace Elementor;

class ORRF_Widget extends Widget_Base {
	
	public function get_name() {
		return 'orrf-forms';
	}
	
	public function get_title() {
		return esc_html__('OpenTable Restaurant Reservation Forms', 'orrf');
	}
	
	public function get_icon() {
		return 'eicon-menu-toggle';
	}
	
	public function get_categories() {
		return [ 'modeltheme-widgets' ];
	}

   protected function register_controls() {

        $this->start_controls_section(
            'section_title',
            [
                'label' => esc_html__( 'General Options', 'orrf' ),
            ]
        );
        $this->add_control(
            'select',
            [
                'label' => esc_html__( 'Select Domain', 'emaf' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'action_url',
                'options' => [
                    'action_url'  => esc_html__( 'Action URL', 'emaf' ),
                    'action_id' => esc_html__( 'Action ID', 'emaf' ),
                ],
            ]
        );
        $this->add_control(
            'action_url',
            [
                'label' => esc_html__( 'Restaurant Link', 'orrf' ),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'placeholder' => esc_html__( 'Example: https://www.opentable.com/gaucho-piccadilly', 'orrf' ),
                'condition' => [
                    'select' => 'action_url',
                ],
                'default' => 'https://www.opentable.com/gaucho-piccadilly',
            ]
        );
        $this->add_control(
            'action_id',
            [
                'label' => esc_html__( 'Restaurant ID', 'orrf' ),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'placeholder' => esc_html__( 'Example: 111100', 'orrf' ),
                'condition' => [
                    'select' => 'action_id',
                ],
                'default' => '111100',
            ]
        );
        $this->add_control(
            'heading',
            [
                'label' => esc_html__( 'Heading', 'orrf' ),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'placeholder' => esc_html__( 'Example: Make a reservation', 'orrf' ),
                'default' => 'Make a reservation',
            ]
        );
        $this->add_control(
            'max_guests',
            [
                'label' => esc_html__( 'Max Guests', 'orrf' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 20,
                'step' => 1,
                'default' => 20,
            ]
        );
        $this->add_control(
            'submit_button_label',
            [
                'label' => esc_html__('Submit Button Label', 'orrf'),
                'type' => Controls_Manager::TEXT,
                'description ' => esc_html__('ex: Submit', 'orrf'),
                'default' => 'Find a Time',
            ]
        );
        $this->end_controls_section();
        $this->start_controls_section(
            'style_section',
            [
                'label' => esc_html__( 'Style Options', 'orrf' ),
            ]
        );
        $this->add_control(
            'color',
            [
                'type' => \Elementor\Controls_Manager::COLOR,
                'label' => esc_html__( 'Button Text Color', 'orrf' ),
                'selectors' => [
                    '{{WRAPPER}} .orrf-submit' => 'color: {{VALUE}} !important',
                ],
                'default' => '#fff',
            ]
        );
        $this->add_control(
            'color_hover',
            [
                'label' => esc_html__( 'Button Text Color Hover', 'orrf' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .orrf-submit:hover' => 'color: {{VALUE}} !important',
                ],
                'default' => '#fff',
            ]
        );
        $this->add_control(
            'bg_color',
            [
                'type' => \Elementor\Controls_Manager::COLOR,
                'label' => esc_html__( 'Button Color', 'orrf' ),
                'selectors' => [
                    '{{WRAPPER}} .orrf-submit' => 'background-color: {{VALUE}} !important',
                ],
                'default' => '#DA3743',
            ]
        );
        $this->add_control(
            'bg_color_hover',
            [
                'label' => esc_html__( 'Button Color Hover', 'orrf' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .orrf-submit:hover' => 'background-color: {{VALUE}} !important',
                ],
                'default' => '#B8222D',
            ]
        );
        $this->end_controls_section();

    }
	
	protected function render() {
        $settings 					= $this->get_settings_for_display();
        $action_url                = $settings['action_url'];
        $action_id                = $settings['action_id'];
        $max_guests                 = $settings['max_guests'];
        $submit_button_label        = $settings['submit_button_label'];
        $color                      = $settings['color'];
        $color_hover                = $settings['color_hover'];
        $bg_color                   = $settings['bg_color'];
        $bg_color_hover             = $settings['bg_color_hover'];
        $heading                    = $settings['heading'];
        $select                    = $settings['select'];


        $shortcode_content = '';

        $shortcode_content .= do_shortcode('[orrf-builder-shortcode 
            action_url="'.esc_attr($action_url).'"  
            action_id="'.esc_attr($action_id).'"  
            max_guests="'.esc_attr($max_guests).'" 
            color="'.esc_attr($color).'" 
            color_hover="'.esc_attr($color_hover).'" 
            bg_color="'.esc_attr($bg_color).'" 
            bg_color_hover="'.esc_attr($bg_color_hover).'" 
            submit_button_label="'.esc_attr($submit_button_label).'" 
            heading="'.esc_attr($heading).'" 
            select="'.esc_attr($select).'"]');

        echo  do_shortcode($shortcode_content);
	}
	
	protected function content_template() {

    }
}
